@@ -150,10 +150,10 @@ def create_context(data):
     """
     context = {'extension' : { OBJECTS_URI['session'] +'/ID' : str(data['sessionID']) }}
     if data['eventType'] == 'L1Test':
-        context['extension'].update(OBJECTS_URI['plugin']+'/L1Test/SelectedFunction',data['selected'])
+        context['extension'][OBJECTS_URI['plugin']+'/L1Test/SelectedFunction'] = data['selected']
     #pas moyen de le trouver
     if data['eventType'] == 'Session_start' :
         if data['L1Test']  :
-            context['extension'].update(OBJECTS_URI['plugin'],OBJECTS_URI['plugin']+'/L1Test')
+            context['extension'][OBJECTS_URI['plugin']] =  OBJECTS_URI['plugin']+'/L1Test'
     return context
 
